mc_eaf_to_mcr converts EAF files produced by the linguistic annotation
software ELAN into a multicastR table. The EAF files must have the correct
tier structure and names, specifically those used for the Multi-CAST
collection: ...
mc_eaf_to_mcr(readfrom = getwd(), recursive = FALSE, write = FALSE,
writeto = getwd(), filename = "")Directory from which to read EAF files. Defaults to the current working directory.
Logical. If TRUE, recurses into subdirectories.
Logical. If TRUE, create an output file in txt
format.
If write is TRUE, a directory to which to write
output. Defaults to getwd. Ignored if write is FALSE.
A length 1 character vector containing the name of the
written output. If empty, defaults to "multicast_YYMM", where 'YY' are the
last two digits of the current year and 'MM' the current month. Ignored if
write is FALSE.
A data.table of the form produced by
multicast, containing the annotation values of the EAF files
read.